*******************************************************************************
* This do-file contains the analysis required for the reproduction of the paper 
* Flip a coin or vote? 
*
* publised in experimental economics, 2021
*
***File created on 2021-05-28  (yyyy-mm-dd) by Sander Renes
					  *
*******************************************************************************
* file assumes the working directory is the source location and the folders
* 'Data_files' and 'output' exist in the same directory
* All data files are assumed to exist in the Data_files folder 
* data files required are:
* timeQuestionaireOK.dta
* transfer_summary.xls
* experimental_data_flip_a_coin.dta
*******************************************************************************
*
*


* SET CORRECT WORKING DIRECTORY FOR EASE OF USE
*cd 

**************Reorganize the data so that figures can be made in R************
****** reorganized data is stored in csv to be loaded in R in the Data_files folder
****** code generates 2 files "data_AdInterim_comparisons.csv", "data_ExAnte_comparisons.csv"  
****** the script "2. choice_comparisons.R" creates the figures.
******  R with ggplot2 allow the new figures to be defined


// ad interim choices per valuation pos/neg
use "Data_files\experimental_data_flip_a_coin.dta", clear

set more off
cap log close

// select the ad interim rounds via the indicator dummy
keep if ad_interim_round==1
/// use the dummy variables chose_* that are 1 if the given mechanism is chosen by this subject and 0 otherwise to summarize choices. 
// Outcome variables give the fraction of of subjects in a given choice that chose each alternative for subjects with positive and negative valuation separately 
collapse (sum) chose_*, by(treatment_distribution  BinaryChoice valuation_positive) 
egen total = rowtotal(chose_*)
export delimited using "Data_files\data_AdInterim_comparisons.csv", replace



// ad interim mechanism choices per type

use "Data_files\experimental_data_flip_a_coin.dta", clear

set more off
cap log close

// select the ad interim rounds via the indicator dummy
keep if ad_interim_round==1
/// use the dummy variables chose_* that are 1 if the given mechanism is chosen by this subject and 0 otherwise to summarize choices. 
// Outcome variables give the fraction of of subjects in a given choice that chose each alternative for subjects with positive and negative valuation separately 

collapse (sum) chose_*, by(treatment_distribution BinaryChoice Valuation) 
egen total = rowtotal(chose_*)

// alternative export versions
export delimited using "Data_files\data_AdInterim_perType_comparisons", replace


/// ex ante comparisons

use "Data_files\experimental_data_flip_a_coin.dta", clear

set more off
cap log close

// select the ad interim rounds via the indicator dummy
keep if ad_interim_round==0 

/// use the dummy variables chose_* that are 1 if the given mechanism is chosen by this subject and 0 otherwise to summarize choices. 
// Outcome variables give the fraction of of subjects in a givven choice that chose each alternative for subjects with positive and negative valuation separately 
collapse (sum) chose_*, by(treatment_distribution BinaryChoice) 
egen total = rowtotal(chose_*)

// alternative export versions
export delimited using "Data_files\data_ExAnte_comparisons.csv", replace
// outsheet using "Data_files\data_ExAnte_comparisons.csv", comma replace
// save using "Data_files\data_exAnte_comparisons.dta", replace


********************* statistical analysis *****************************
use "Data_files\experimental_data_flip_a_coin.dta", clear


** Table 1: 
** Distribution of valuations for public project and number of observations by treatment
* data in table is hand-typed, collected from following overviews:
// subjects
by treatment_number identifier, sort: gen nvals2 = _n == 1
tab nvals treatment_number if nvals2==1

// match-groups
by session_match treatment_number, sort: gen nvals1 = _n == 1
tab nvals1 treatment_number if nvals1==1

/// Section 5.1 

// table 3
// Prediction 1, money-maximizing under full rationality

//  logit simply based on positive / negative valuation over all treatments,
// 1.1 valuation should not matter ex ante, but treatment dummies should show favor for efficient mechanisms, 
logit efficient_mech_choice valuation_negative ibn.treatment_number if ex_ante_round==1, vce(cluster session_match) nocons
outreg2 using output/Rational_selfIntersted.xls, excel replace addtext(Clusters, `e(N_clust)' , Cl-level, match, Prediction, 1.1, Stage, Ex Ante, Choices, ALL) 
// bigggest difference between symmetric and right skewed treatment, p=0.07 so marginally significant. 


// 1.2, with private information, the individuals with negative valuation prefer NSQ over everything, Myerson-Satterthwaite 
logit chose_NSQ valuation_negative ibn.treatment_number if ad_interim_round==1, vce(cluster session_match) nocons
outreg2 using output/Rational_selfIntersted.xls, excel addtext(Clusters, `e(N_clust)' , Cl-level, match, Prediction, 1.2, Stage, Ad Interim, Choices, NSQ vs. Other ) 
test (1.treatment_number+valuation_negative=0)
test (2.treatment_number+valuation_negative=0)
test (3.treatment_number+valuation_negative=0)
test (4.treatment_number+valuation_negative=0)


//1.2 same idea, now with dummies per valuation and setting value== -1 as zero
// 2 of the negative dummies are dropped because of colinearity and lack of variation (all chose NSQ)
// all positive valuations significantly less likely to choose NSQ, abs(coefficient) all larger than constant. 
// p-values on positive valuations <0.0001 
logit chose_NSQ ibn.Value_factor ib1.treatment_number  if ad_interim_round==1, vce(cluster session_match) nocons
Prediction, 1.2, Stage, Ad Interim, Choices, NSQ vs. Other )
test (2.treatment_number+4.Value_factor=0)
test (3.treatment_number+4.Value_factor=0)
test (4.treatment_number+4.Value_factor=0)


// 1.3, AGV and SM prefered over RAND by all types ad-interim. 
//
logit chose_RAND ibn.Value_factor  ib1.treatment_number if ad_interim_round==1 & (Rule_1==1|Rule_2==1|Rule_1==2|Rule_2==2), vce(cluster session_match)  nocons
outreg2 using output/Rational_selfIntersted.xls, excel addtext(Clusters, `e(N_clust)' , Cl-level, match, Prediction, 1.3, Stage, Ad Interim, Choices, AGV/SM Vs. RAND )
test (2.treatment_number+2.Value_factor=0)
test (3.treatment_number+6.Value_factor=0)
test (4.treatment_number+2.Value_factor=0)


//1.4 Gruner Koriyama predictions
//


// sign correct,  p<0.001
logit chose_AGV GK_prefAGV ibn.treatment_number if BinaryChoice==12, vce(cluster session_match) nocons
outreg2 using output/Rational_selfIntersted.xls, excel addtext(Clusters, `e(N_clust)' , Cl-level, match, Prediction, 1.4, Stage, Ad Interim, Choices, AGV Vs. SM  )
test (1.treatment_number+GK_prefAGV=0)
test (2.treatment_number+GK_prefAGV=0)
test (3.treatment_number+GK_prefAGV=0)
test (4.treatment_number+GK_prefAGV=0)

//note that we are still only talking about a limited number of cases, but still a reasonable impact.
tab chose_AGV GK_prefAGV, chi col




// SECTION 5.2 Social concerns, Prediction 2

////////////////////////////////////////////////////////////////////////////////////
// Hypothesis 2, Grunner Engelmann and friends, suggest that fairness matters. Here the right-skewed treatment and the robustness treatment give the AGV a tax-the-winner property, while all proceeds of the tax go to the losing players, so that inequality is reduced. The left-skewed treatment does the opposite by taxing the loser. 
// results indicate that there might be a small (non-significant) increase in likelihood that the AGV is chosen in the ex-ante rounds of the right-skewed treatment, but definately not in the ad-interim rounds. 
// extreme types 7 and -7 have a Veto in ad-interim rounds, compare to that effect
/*
generate TaxTheWinner=0 if treatment_number==3
replace TaxTheWinner=1 if treatment_number==2 | treatment_number==4 
generate absVal = abs(Valuation)
generate Veto=0 if treatment_number==3|treatment_number==2 | treatment_number==4 
replace Veto=1 if (treatment_number==3|treatment_number==2) & absVal==7 & ad_interim_round==1
*/

// Table 4:
// Effect of social concerns on mechanism choices

// logistic to see if it matters at all, 
xi: logit chose_AGV i.ad_interim_round*TaxTheWinner, vce(cluster session_match)
outreg2 using output/Other_assumptions.xls, excel replace addtext(Clusters, `e(N_clust)' , Cl-level, match, Hypothesis, H2, Choices, AGV vs other , Treatments, not symmetric, types, all)
test (TaxTheWinner + _Iad_XTaxTh_1=0)
//no significant effect found for tax-the-winner, only the information effect (i.e. the shift from ex ante to ad-interim) is found. 

// logistic to see if it matters at all, restricted to types that occur in both treatments (1 and -1)
xi: logit chose_AGV i.ad_interim_round*TaxTheWinner if absVal==1, vce(cluster session_match) 
outreg2 using output/Other_assumptions.xls, excel addtext(Clusters, `e(N_clust)' , Cl-level, match, Hypothesis, H2, Choices, AGV vs other, Treatments, not symmetric, types, AbsVal=1 )
test (TaxTheWinner + _Iad_XTaxTh_1=0)
//no effects found if we restrict the observations to types that occur in both treatments



// tests for presentation order effects, use a logit to see if the mechanism 
// chosen is related to the order of comparison in all binary choices 
// zero found, smallest p-value: 0.137
bysort BinaryChoice: logit chose_AGV comparison_order_inverted  
bysort BinaryChoice: logit chose_SM comparison_order_inverted  
bysort BinaryChoice: logit chose_NSQ comparison_order_inverted  


/////////////////////////////////////////////////
///// APPENDIX FIGURES AND TABLES
/////////////////////////////////////////////////

// Table 10 Mechanisms chosen by a majority of subjects in the first 6 ex-ante rounds
// data for table:

forvalues TM = 1(1)4 {
		foreach comp of numlist 12 13 14 23 24 34 {
			bitest Rule_Vote == 0.5 if Period <= 6 & ///
				BinaryChoice == `comp' & ///
				treatment_number == `TM' 
		
		local value_label_dist : label (treatment_number) `TM'
		local value_label_comp : label (BinaryChoice) `comp'
		dis "Binary choice between: "  "`value_label_comp'"  ", Treatment: " "`value_label_dist'" 
		dis "Result (p-value): " r(p)
		}
}


/// Table 11: Percentage of subjects who chose each mechanism in the ex-ante rounds

// note that the Rule_Vote variable captures if the first variable in the comparison is chosen.
// For percentages higher than 50%, therefore the first mechanism is added in the table (by hand)
// for percentages under 50% the second variable is added in the table.

collapse (mean) Rule_Vote , by (BinaryChoice block treatment_number)
export excel using "output/table11_data_average_MechChoice_ExAnte"


// Figure 2: Comparing mechanism choices with positive and nageative valuation in all treatments. 

*** Binary choice results by positive/negative private valuation (treatment one)

*Graph that shows that NSQ is preferred over all other mechnsims ad interim if 
*the subject has a negative private valuation. However NSQ is not preferred with
*positive valuation.
*Ex ante: No difference depeding on valuation (as it should be the case). 

use "Data_files\experimental_data_flip_a_coin.dta", clear
cd "output"

histogram GroupDecisionVote if Period < 13 & treatment_distribution == 0 & ///
	(BinaryChoice == 13 ) , ///
	discrete fraction ylabel(0(0.20)1.1, grid) ///
	addlabel xlabel(1(2)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("AGV vs. NSQ", color(black)))

graph save graph1.gph, replace
*For treatment 1 by actual valuation

histogram GroupDecisionVote if Period < 13 & treatment_distribution == 0 & ///
	(BinaryChoice == 23 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(2(1)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("SM vs. NSQ", color(black)))

graph save graph2.gph, replace
*For treatment 1 by actual valuation

histogram GroupDecisionVote if Period < 13 & treatment_distribution == 0 & ///
	(BinaryChoice == 34 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(3(1)4, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("NSQ vs. RAND", color(black)))

graph save graph3.gph, replace
*For treatment 1 by actual valuation

graph combine graph1.gph graph2.gph graph3.gph, rows(1) graphregion(fcolor(white) margin(zero) lcolor(white)) title("ex ante", color(black))
graph save graph_row_1.gph, replace

histogram GroupDecisionVote if Period > 12 & treatment_distribution == 0 & ///
	(BinaryChoice == 13 ) , ///
	discrete fraction ylabel(0(0.20)1.1, grid) ///
	addlabel xlabel(1(2)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle(" ") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("AGV vs. NSQ", color(black)))

graph save graph21.gph, replace
*For treatment 1 by actual valuation

histogram GroupDecisionVote if Period > 12 & treatment_distribution == 0 & ///
	(BinaryChoice == 23 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(2(1)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("Chosen mechanism") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("SM vs. NSQ", color(black)))

graph save graph22.gph, replace
*For treatment 1 by actual valuation

histogram GroupDecisionVote if Period > 12 & treatment_distribution == 0 & ///
	(BinaryChoice == 34 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(3(1)4, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle(" ") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("NSQ vs. RAND", color(black)))

graph save graph23.gph, replace
*For treatment 1 by actual valuation

graph combine graph21.gph graph22.gph graph23.gph, rows(1) graphregion(fcolor(white) margin(zero) lcolor(white)) title("ad interim", color(black))
graph save graph_row_2.gph, replace

graph combine graph_row_1.gph graph_row_2.gph, rows(2) graphregion(fcolor(white) margin(zero) lcolor(white)) 

graph export "Results_MS_TM1_new.png", replace
graph export "Results_MS_TM1_new.eps", replace
graph drop _all


**TM2 (right skewed)

histogram GroupDecisionVote if Period < 13 & treatment_distribution == 1 & ///
	(BinaryChoice == 13 ) , ///
	discrete fraction ylabel(0(0.20)1.1, grid) ///
	addlabel xlabel(1(2)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("AGV vs. NSQ", color(black)))

graph save graph1.gph, replace
*For treatment 2 by actual valuation

histogram GroupDecisionVote if Period < 13 & treatment_distribution == 1 & ///
	(BinaryChoice == 23 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(2(1)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("SM vs. NSQ", color(black)))

graph save graph2.gph, replace
*For treatment 2 by actual valuation

histogram GroupDecisionVote if Period < 13 & treatment_distribution == 1 & ///
	(BinaryChoice == 34 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(3(1)4, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("NSQ vs. RAND", color(black)))

graph save graph3.gph, replace
*For treatment 2 by actual valuation

graph combine graph1.gph graph2.gph graph3.gph, rows(1) graphregion(fcolor(white) margin(zero) lcolor(white)) title("ex ante", color(black))
graph save graph_row_1.gph, replace

histogram GroupDecisionVote if Period > 12 & treatment_distribution == 1 & ///
	(BinaryChoice == 13 ) , ///
	discrete fraction ylabel(0(0.20)1.1, grid) ///
	addlabel xlabel(1(2)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle(" ") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("AGV vs. NSQ", color(black)))

graph save graph21.gph, replace
*For treatment 2 by actual valuation

histogram GroupDecisionVote if Period > 12 & treatment_distribution == 1 & ///
	(BinaryChoice == 23 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(2(1)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("Chosen mechanism") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("SM vs. NSQ", color(black)))

graph save graph22.gph, replace
*For treatment 2 by actual valuation

histogram GroupDecisionVote if Period > 12 & treatment_distribution == 1 & ///
	(BinaryChoice == 34 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(3(1)4, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle(" ") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("NSQ vs. RAND", color(black)))

graph save graph23.gph, replace
*For treatment 2 by actual valuation

graph combine graph21.gph graph22.gph graph23.gph, rows(1) graphregion(fcolor(white) margin(zero) lcolor(white)) title("ad interim", color(black))
graph save graph_row_2.gph, replace

graph combine graph_row_1.gph graph_row_2.gph, rows(2) graphregion(fcolor(white) margin(zero) lcolor(white)) 

graph export "Results_MS_TM2_new.png", replace
graph export "Results_MS_TM2_new.eps", replace
graph drop _all

**TM3

histogram GroupDecisionVote if Period < 13 & treatment_distribution == -1 & ///
	(BinaryChoice == 13 ) , ///
	discrete fraction ylabel(0(0.20)1.1, grid) ///
	addlabel xlabel(1(2)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("AGV vs. NSQ", color(black)))

graph save graph1.gph, replace
*For treatment 3 by actual valuation

histogram GroupDecisionVote if Period < 13 & treatment_distribution == -1 & ///
	(BinaryChoice == 23 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(2(1)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("SM vs. NSQ", color(black)))

graph save graph2.gph, replace
*For treatment 3 by actual valuation

histogram GroupDecisionVote if Period < 13 & treatment_distribution == -1 & ///
	(BinaryChoice == 34 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(3(1)4, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("NSQ vs. RAND", color(black)))

graph save graph3.gph, replace
*For treatment 3 by actual valuation

graph combine graph1.gph graph2.gph graph3.gph, rows(1) graphregion(fcolor(white) margin(zero) lcolor(white)) title("ex ante", color(black))
graph save graph_row_1.gph, replace

histogram GroupDecisionVote if Period > 12 & treatment_distribution == -1 & ///
	(BinaryChoice == 13 ) , ///
	discrete fraction ylabel(0(0.20)1.1, grid) ///
	addlabel xlabel(1(2)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle(" ") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("AGV vs. NSQ", color(black)))

graph save graph21.gph, replace
*For treatment 3 by actual valuation

histogram GroupDecisionVote if Period > 12 & treatment_distribution == -1 & ///
	(BinaryChoice == 23 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(2(1)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("Chosen mechanism") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("SM vs. NSQ", color(black)))

graph save graph22.gph, replace
*For treatment 3 by actual valuation

histogram GroupDecisionVote if Period > 12 & treatment_distribution == -1 & ///
	(BinaryChoice == 34 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(3(1)4, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle(" ") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("NSQ vs. RAND", color(black)))

graph save graph23.gph, replace
*For treatment 3 by actual valuation

graph combine graph21.gph graph22.gph graph23.gph, rows(1) graphregion(fcolor(white) margin(zero) lcolor(white)) title("ad interim", color(black))
graph save graph_row_2.gph, replace

graph combine graph_row_1.gph graph_row_2.gph, rows(2) graphregion(fcolor(white) margin(zero) lcolor(white)) 

graph export "Results_MS_TM3_new.png", replace
graph export "Results_MS_TM3_new.eps", replace
graph drop _all

**TM4 (control TM)

histogram GroupDecisionVote if Period < 13 & treatment_distribution == -2 & ///
	(BinaryChoice == 13 ) , ///
	discrete fraction ylabel(0(0.20)1.1, grid) ///
	addlabel xlabel(1(2)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("AGV vs. NSQ", color(black)))

graph save graph1.gph, replace
*For treatment 4 by actual valuation

histogram GroupDecisionVote if Period < 13 & treatment_distribution == -2 & ///
	(BinaryChoice == 23 ) , ///
	discrete fraction  ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(2(1)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("SM vs. NSQ", color(black)))

graph save graph2.gph, replace
*For treatment 4 by actual valuation

histogram GroupDecisionVote if Period < 13 & treatment_distribution == -2 & ///
	(BinaryChoice == 34 ) , ///
	discrete fraction   ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(3(1)4, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("NSQ vs. RAND", color(black)))

graph save graph3.gph, replace
*For treatment 4 by actual valuation

graph combine graph1.gph graph2.gph graph3.gph, rows(1) ycommon graphregion(fcolor(white) margin(zero) lcolor(white)) title("ex ante", color(black)) 
graph save graph_row_1.gph, replace

histogram GroupDecisionVote if Period > 12 & treatment_distribution == -2 & ///
	(BinaryChoice == 13 ) , ///
	discrete fraction ylabel(0(0.20)1.1, grid) ///
	addlabel xlabel(1(2)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle(" ") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("AGV vs. NSQ", color(black)))

graph save graph21.gph, replace
*For treatment 4 by actual valuation

histogram GroupDecisionVote if Period > 12 & treatment_distribution == -2 & ///
	(BinaryChoice == 23 ) , ///
	discrete fraction   ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(2(1)3, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle("Chosen mechanism") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("SM vs. NSQ", color(black)))

graph save graph22.gph, replace
*For treatment 4 by actual valuation

histogram GroupDecisionVote if Period > 12 & treatment_distribution == -2 & ///
	(BinaryChoice == 34 ) , ///
	discrete fraction   ///
	ylabel(0(0.20)1.1, grid tlcolor(white) labcolor(white)) ymtick(none, nolabels noticks grid) yscale(noline) ytitle("") ///
	addlabel xlabel(3(1)4, labels valuelabel) ///
	fcolor(gray) lcolor(black) ///
	xtitle(" ") ///
	subtitle( , fcolor(white) lcolor(white) box bexpand) ///
	plotregion(fcolor(white) margin(zero) lcolor(white)) ///
	by( , legend(off) note("")) ///
	by(, graphregion(fcolor(white) margin(zero) lcolor(white)) )	///	
	by(valuation_negative, title("NSQ vs. RAND", color(black)))

graph save graph23.gph, replace
*For treatment 1 by actual valuation

graph combine graph21.gph graph22.gph graph23.gph, rows(1) graphregion(fcolor(white) margin(zero) lcolor(white)) title("ad interim", color(black)) ycommon
graph save graph_row_2.gph, replace

graph combine graph_row_1.gph graph_row_2.gph, rows(2) graphregion(fcolor(white) margin(zero) lcolor(white)) 

graph export "Results_MS_TM4_new.png", replace
graph export "Results_MS_TM4_new.eps", replace
graph drop _all

cd ..

// table 12 
use "Data_files\experimental_data_flip_a_coin.dta", clear

// note that the Rule_Vote variable captures if the first variable in the comparison is chosen.
// For percentages higher than 50%, therefore the first mechanism is added in the table (by hand)
// for percentages under 50% the second variable is added in the table.

collapse (sum) Rule_Vote (count) total=Rule_Vote if block==3, by (BinaryChoice treatment_distribution Valuation)
export excel using "output/table12_data_proportion_MechChoice_AdInterim"


// table 13 
use "Data_files\experimental_data_flip_a_coin.dta", clear
// data for table
bysort treatment_distribution: tab Valuation reported_valuation if GroupDecisionRule==1 & ex_ante_round==1


tab2xl Valuation reported_valuation if GroupDecisionRule==1 & treatment_distribution==0 & ex_ante_round==1 using "output/table13_Val_RepVal.xlsx", row(3) col(2) replace
putexcel set "output/table13_Val_RepVal.xlsx", sheet(Sheet1) modify
putexcel D1 = "Symmetric treatment"
putexcel D2 = "Reported Valuation "

tab2xl Valuation reported_valuation if GroupDecisionRule==1 & treatment_distribution==1 & ex_ante_round==1 using "output/table13_Val_RepVal.xlsx", row(3) col(10) 
putexcel set "output/table13_Val_RepVal.xlsx", sheet(Sheet1) modify
putexcel L1 = "Right Skewed treatment"
putexcel L2 = "Reported Valuation "

tab2xl Valuation reported_valuation if GroupDecisionRule==1 & treatment_distribution==-1 & ex_ante_round==1 using "output/table13_Val_RepVal.xlsx", row(11) col(2) 
putexcel set "output/table13_Val_RepVal.xlsx", sheet(Sheet1) modify
putexcel D9 = "left Skewed treatment"
putexcel D10 = "Reported Valuation "

tab2xl Valuation reported_valuation if GroupDecisionRule==1 & treatment_distribution==-2 & ex_ante_round==1 using "output/table13_Val_RepVal.xlsx", row(11) col(10) 
putexcel set "output/table13_Val_RepVal.xlsx", sheet(Sheet1) modify
putexcel L9 = "Robustness treatment"
putexcel L10 = "Reported Valuation "

