######################################################################################
##
##  This file was created by Sander Renes, 18-08-2020 as part of the revisions for the paper
##  "Flip a coin or vote? An experiment on the implementation and efficiency of social choice mechanisms"
##  published in  Experimental Economics , 2021
##  It creates figure 1 with an overview of all mechanism choices. 
##  code assumes that the required data, generated by STATA, 
##  is present in "Data_files/data_ExAnte_comparisons.csv"  
##  The figure is saved in the folder "output" also assumed to be in current folder
##
##
##  This version is dated 2021-05-28
##
##########################################################
library(ggplot2)
library(dplyr)
library(readr)
library(ggpubr)

## SET CORRECT WORKING DIRECTORY FOR EASE OF USE 
#setwd("")


## function reads the data from the STATA files and does the lay-out and percentage calculations used in all 3 subfigures
prep_data<-function(df) {
  ## set a variable, 'percentage' 
  ## percentage is the fraction of efficient choices in a comparison that tan be mapped on the axis directly in the picture
   df<- df %>% mutate(percentage = case_when(BinaryChoice=="AGV vs. SM" ~ chose_AGV/total,
                                                                    BinaryChoice=="AGV vs. NSQ" ~ chose_AGV/total,
                                                                    BinaryChoice=="AGV vs. RAND" ~ chose_AGV/total,
                                                                    BinaryChoice=="SM vs. NSQ" ~ chose_SM/total,
                                                                    BinaryChoice=="SM vs. RAND" ~ chose_SM/total,
                                                                    BinaryChoice=="NSQ vs. RAND" ~ chose_RAND/total,
                                                                    TRUE ~ -1))
  
  ## lay-out of the axis requires that we set variable Valgin and Halign 
  ## indicating wether the comparison should be moved up/down and left/right in the picture
  ## InvertX tells the lay-out to move from right to left for the SM-RAND comparison
   df<- df %>% mutate(Halign=case_when(BinaryChoice=="AGV vs. RAND" ~ 1,
                                                       BinaryChoice=="SM vs. NSQ" ~ -1,
                                                       TRUE ~ 0) )%>% 
    mutate(Valign=case_when(BinaryChoice=="AGV vs. SM" ~ 1,
                            BinaryChoice=="NSQ vs. RAND" ~ -1,
                            TRUE ~ 0))%>%
    mutate(InvertX=case_when(BinaryChoice=="SM vs. RAND" ~ 1,
                             TRUE ~ 0))
   ## set lay-out issues in data prep so all pics look the same
   
   
   # map the percentage to both x and y and fix the names and order of the treatments for the pictures
   df<- df %>% mutate(x=percentage,y=percentage) %>% rename(Treatment=treatment_distribution) 
   df$Treatment<-as.factor(df$Treatment)%>% recode_factor("symmetric"="Symmetric", "+7"="Right skewed", "-7"="Left skewed", "three neg"="Robustness",.ordered=TRUE)
    # correct the x and y for the edge comparisons
   df$y[df$Valign==-1]=-Corner_space
   df$y[df$Valign==1]=1+Corner_space
   df$x[df$Halign==-1]=-Corner_space
   df$x[df$Halign==1]=1+Corner_space
   # invert the percentage for the RAND - SM comparison
   df$x[df$InvertX==1]=1-df$percentage[df$InvertX==1]
   
    return(df)
}


## Corner_space determines the offset of the edge comparisons from the simplex,
# needs to be used in several places so it is set in the general environment
Corner_space=0.09

## read data 
data_exAnte_comparisons  <- read_csv("Data_files/data_ExAnte_comparisons.csv")

## clean data with function above to add the required variables for the plot
d<-prep_data(data_exAnte_comparisons)

## ex-ante plot
ggplot()+ ## ggtitle("Binary mechanism choices, Ex Ante")+
  theme( plot.title = element_text(hjust = 0.5),
         panel.background = element_rect(fill = "white", colour = "white" ), 
         panel.grid.major = element_line(size = 0.5, linetype = 'dashed',  colour = "grey"),
         axis.text.y = element_text(angle = 90, hjust=0.5, size=13),
         axis.text.x = element_text(size=13),
         legend.text=element_text(size=15),
         legend.title = element_text(size=17)) + 
  geom_segment(aes(x=0, y=0, xend=1, yend=1)) +  ## radial axis for comparisons
  geom_segment(aes(x=0, y=1, xend=1, yend=0)) +
  geom_segment(aes(x=0-Corner_space, y=0, xend=0-Corner_space, yend=1)) +  ## box axis for comparisons
  geom_segment(aes(x=0, y=1+Corner_space, xend=1, yend=1+Corner_space)) +
  geom_segment(aes(x=1, y=0-Corner_space, xend=0, yend=0-Corner_space)) +
  geom_segment(aes(x=1+Corner_space, y=0, xend=1+Corner_space, yend=1)) +
  annotate("text", x=-Corner_space, y=-Corner_space, label="NSQ", size=4 ) + ## labels for corners
  annotate("path", x=-Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=-Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  annotate("text", x=-Corner_space, y=1+Corner_space, label="SM", size=4 ) +
  annotate("path", x=-Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=1+Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  annotate("text", x=1+Corner_space, y=-Corner_space, label="RAND", size=4 ) +
  annotate("path", x=1+Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=-Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  annotate("text", x=1.08, y=1.080, label="AGV", size=4 ) +
  annotate("path", x=1+Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=1+Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  coord_cartesian( xlim = c(-.15,1.15),  ylim = c(-.15,1.15),  expand = TRUE,  default = FALSE)+ ## fix limits on axis to ensure annotations fit
  scale_x_continuous('Percentage split', breaks=seq(0,1,0.25), labels=c("100 / 0" , "75 / 25", "50 / 50","25 / 75","0 / 100")) +
  scale_y_continuous('Percentage split', breaks=seq(0,1,0.25), labels=c("100 / 0" , "75 / 25", "50 / 50","25 / 75","0 / 100"))+scale_shape_discrete(solid=FALSE) +
  geom_point(data=d, mapping=aes(x=x, y=y, shape=Treatment),  size=3, fill=NA, stroke = 2) ## data

ggsave("output/Choices_ExAnte.png",  width = 17, height=12, units=c("cm"))




###########################################################
### plot Ad-interim choices

## read data 
data_AdInterim_comparisons <- read_csv("Data_files/data_AdInterim_comparisons.csv")  

## clean data with function above to add the required variables for the plot
d<-prep_data(data_AdInterim_comparisons)

## set labels for positive and negative groups
d$Value[d$valuation_positive==1]<-"Positive"
d$Value[d$valuation_positive==0]<-"Negative"


plot_AdInterim_positive <-   ggplot()+ ggtitle("Positive Valuation")+
  geom_segment(aes(x=0, y=0, xend=1, yend=1)) +  ## radial axis for comparisons
  geom_segment(aes(x=0, y=1, xend=1, yend=0)) +
  geom_segment(aes(x=0-Corner_space, y=0, xend=0-Corner_space, yend=1)) +  ## box axis for comparisons
  geom_segment(aes(x=0, y=1+Corner_space, xend=1, yend=1+Corner_space)) +
  geom_segment(aes(x=1, y=0-Corner_space, xend=0, yend=0-Corner_space)) +
  geom_segment(aes(x=1+Corner_space, y=0, xend=1+Corner_space, yend=1)) +
  annotate("text", x=-Corner_space, y=-Corner_space, label="NSQ", size=4 ) + ## labels for corners
  annotate("path", x=-Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=-Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  annotate("text", x=-Corner_space, y=1+Corner_space, label="SM", size=4 ) +
  annotate("path", x=-Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=1+Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  annotate("text", x=1+Corner_space, y=-Corner_space, label="RAND", size=4 ) +
  annotate("path", x=1+Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=-Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  annotate("text", x=1.08, y=1.080, label="AGV", size=4 ) +
  annotate("path", x=1+Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=1+Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  coord_cartesian( xlim = c(-.15,1.15),  ylim = c(-.15,1.15),  expand = TRUE,  default = FALSE)+ ## fix limits of the axis to ensure annotations fit
  scale_x_continuous('Percentage split', breaks=seq(0,1,0.25), labels=c("100 / 0" , "75 / 25", "50 / 50","25 / 75","0 / 100")) +
  scale_y_continuous('Percentage split', breaks=seq(0,1,0.25), labels=c("100 / 0" , "75 / 25", "50 / 50","25 / 75","0 / 100"), position = "right")+scale_shape_discrete(solid=FALSE) +
  theme( plot.title = element_text(hjust = 0.5),
         panel.background = element_rect(fill = "white", colour = "white" ), 
         panel.grid.major = element_line(size = 0.5, linetype = 'dashed',  colour = "grey"),
         axis.text.y = element_text(angle = 90, size=13, vjust = 1 , hjust = 1),
         axis.text.y.right = element_text( hjust=0.5),
         axis.text.x = element_text(size=13, hjust=0.5 ))+ 
   geom_point(data=d[d$Value=="Positive",], mapping=aes(x=x, y=y, shape=Treatment),  size=3, fill=NA, stroke = 2)  ## data



plot_AdInterim_negative <- ggplot()+ ggtitle("Negative Valuation")+
  theme( plot.title = element_text(hjust = 0.5),
         panel.background = element_rect(fill = "white", colour = "white" ), 
         panel.grid.major = element_line(size = 0.5, linetype = 'dashed',  colour = "grey"),
         axis.text.y = element_text(angle = 90, hjust=0.5, size=13),
         axis.text.x = element_text(size=13)    )+ 
  geom_segment(aes(x=0, y=0, xend=1, yend=1)) +  ## radial axis for comparisons
  geom_segment(aes(x=0, y=1, xend=1, yend=0)) +
  geom_segment(aes(x=0-Corner_space, y=0, xend=0-Corner_space, yend=1)) +  ## box axis for comparisons
  geom_segment(aes(x=0, y=1+Corner_space, xend=1, yend=1+Corner_space)) +
  geom_segment(aes(x=1, y=0-Corner_space, xend=0, yend=0-Corner_space)) +
  geom_segment(aes(x=1+Corner_space, y=0, xend=1+Corner_space, yend=1)) +
  annotate("text", x=-Corner_space, y=-Corner_space, label="NSQ", size=4 ) + ## labels for corners
  annotate("path", x=-Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=-Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  annotate("text", x=-Corner_space, y=1+Corner_space, label="SM", size=4 ) +
  annotate("path", x=-Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=1+Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  annotate("text", x=1+Corner_space, y=-Corner_space, label="RAND", size=4 ) +
  annotate("path", x=1+Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=-Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  annotate("text", x=1.08, y=1.080, label="AGV", size=4 ) +
  annotate("path", x=1+Corner_space+Corner_space*cos(seq(0,2*pi,length.out=100)),y=1+Corner_space+Corner_space*sin(seq(0,2*pi,length.out=100)))+
  coord_cartesian( xlim = c(-.15,1.15),  ylim = c(-.15,1.15),  expand = TRUE,  default = FALSE)+ ## fix limits of the axis to ensure annotations fit
  scale_x_continuous('Percentage split', breaks=seq(0,1,0.25), labels=c("100 / 0" , "75 / 25", "50 / 50","25 / 75","0 / 100")) +
  scale_y_continuous('Percentage split', breaks=seq(0,1,0.25), labels=c("100 / 0" , "75 / 25", "50 / 50","25 / 75","0 / 100"))+scale_shape_discrete(solid=FALSE) +
  geom_point(data=d[d$Value=="Negative",], mapping=aes(x=x, y=y, shape=Treatment),  size=3, fill=NA, stroke = 2) ## data


##ggarrange(plot_AdInterim_negative, plot_AdInterim_positive,common.legend = TRUE, legend = "bottom")

ggarrange(plot_AdInterim_negative, plot_AdInterim_positive,common.legend = TRUE, legend = FALSE)
ggsave("output/Choices_AdInterim_DualPlot.png",  width = 24, height=12, units=c("cm"))

